@@ -18,7 +18,7 @@ WIKILINKB = FRONTBOUND + r'(~?[A-Z][a-z]+[A-Z]\w+\b)'
 FREELINK = FREELINKB + '(?!@)'
 WIKILINK = WIKILINKB + '(?!@)'
 
-TARGETLINK_BASE = r'(@[0-9a-z][0-9a-z\-]*[0-9a-z])(?:\b|$)'
+TARGETLINK_BASE = r'(@[0-9A-Za-z][0-9A-Za-z\-]*[0-9A-Za-z])(?:\b|$)'
 TARGETLINK = FRONTBOUND + TARGETLINK_BASE
 WIKITARGET = WIKILINKB + TARGETLINK_BASE
 FREETARGET = FREELINKB + TARGETLINK_BASE
